@@ -4,20 +4,10 @@ use utf8;
 use 5.014;
 use warnings;
 
-no if $] >= 5.018, warnings => 'experimental::smartmatch';
-
 =head1 NAME
 
 WWW::YoutubeViewer::Utils - Various utils.
 
-=head1 VERSION
-
-Version 0.02
-
-=cut
-
-our $VERSION = '0.02';
-
 =head1 SYNOPSIS
 
     use WWW::YoutubeViewer::Utils;
@@ -169,33 +159,50 @@ sub has_entries {
     !!$req->{results}{pageInfo}{totalResults};
 }
 
-=head2 normalize_video_title($title)
+=head2 normalize_video_title($title, $fat32safe)
 
 Replace file-unsafe characters and trim spaces.
 
 =cut
 
 sub normalize_video_title {
-    my ($self, $title) = @_;
+    my ($self, $title, $fat32safe) = @_;
 
-    if ($^O ~~ [qw(linux freebsd openbsd)]) {
-        $title =~ tr{/}{%};
+    if ($fat32safe) {
+        $title =~ tr{:"*/?\\|}{;'+%$%%};    # "
+        $title =~ tr/<>//d;
     }
     else {
-        $title =~ tr{:"*/?\\|}{;'+%$%%};    # "
+        $title =~ tr{/}{%};
     }
 
     join(q{ }, split(q{ }, $title));
 }
 
-=head2 format_text($streaming=HASH, $video_info=HASH, $text=STRING, $escape=BOOL)
+=head2 format_text(%opt)
 
-Format a text with information from streaming and video info.
+Formats a text with information from streaming and video info.
+
+The structure of C<%opt> is:
+
+    (
+        streaming => HASH,
+        info      => HASH,
+        text      => STRING,
+        escape    => BOOL,
+        fat32safe => BOOL,
+    )
 
 =cut
 
 sub format_text {
-    my ($self, $streaming, $info, $text, $quotemeta) = @_;
+    my ($self, %opt) = @_;
+
+    my $streaming = $opt{streaming};
+    my $info      = $opt{info};
+    my $text      = $opt{text};
+    my $escape    = $opt{escape};
+    my $fat32safe = $opt{fat32safe};
 
     my %special_tokens = (
         ID          => sub { $self->get_video_id($info) },
@@ -210,7 +217,7 @@ sub format_text {
         DURATION    => sub { $self->get_duration($info) },
         TIME        => sub { $self->format_time($self->get_duration($info)) },
         TITLE       => sub { $self->get_title($info) },
-        FTITLE      => sub { $self->normalize_video_title($self->get_title($info)) },
+        FTITLE      => sub { $self->normalize_video_title($self->get_title($info), $fat32safe) },
         CAPTION     => sub { $self->get_caption($info) },
         DESCRIPTION => sub { $self->get_description($info) },
 
@@ -262,7 +269,7 @@ sub format_text {
 
     $text =~ s/$escapes_re/$special_escapes{$1}/g;
 
-    $quotemeta
+    $escape
       ? $text =~ s/$tokens_re/\Q${\$special_tokens{$1}()}\E/gr
       : $text =~ s/$tokens_re/${\$special_tokens{$1}()}/gr;
 }
@@ -473,41 +480,10 @@ You can find documentation for this module with the perldoc command.
 Copyright 2012-2015 Trizen.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
+See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
 
